package jp.veltec.pdf;
import com.lowagie.text.*;			//iTextgAPI
import com.lowagie.text.pdf.*;		//iTextgAPI
import java.awt.Color;
import org.w3c.dom.*;

class PdfCellWrapper extends PdfPCell{

	Font fontM;
	Font fontG;
	String strFontFamily="";

	PdfCellWrapper() throws Exception{
		fontG = new Font(BaseFont.createFont("HeiseiKakuGo-W5", "UniJIS-UCS2-H",false));
		fontM = new Font(BaseFont.createFont("HeiseiMin-W3", "UniJIS-UCS2-H",false));
	}

	void setFontFamily(String fontFamily){
		this.strFontFamily=fontFamily;
	}

	void setFontSize(float size){
		fontM.setSize(size);
		fontG.setSize(size);
	}

	void setFontColor(Color color){
		fontM.setColor(color);
		fontG.setColor(color);
	}

	void setFontStyle(String style){
		//normal, bold, italic, underline, strike
		fontM.setStyle(style);
		fontG.setStyle(style);
	}

	void setFontStyle(int style){
		fontM.setStyle(style);
		fontG.setStyle(style);
	}


	void setString(String str)throws Exception{
		Font font;
		if(strFontFamily.equals("")){
			font=this.fontM;
		}else if(strFontFamily.equals("SVbN")){
			font=this.fontG;
		}else{
			throw new Exception("font family name not match;");
		}
		String[] aryStr = str.split("\\\\n");
		Phrase phrase = new Phrase("",font);
		for(int i=0;i<aryStr.length;i++){
			phrase.add(new Chunk(aryStr[i]));
			phrase.add("\n");
		}
		super.setPhrase(phrase);
	}

	void setAttributes(NamedNodeMap attributes) throws Exception{
		for(int i=0;i<attributes.getLength();i++){
			String strName = attributes.item(i).getNodeName();
			String strValue = attributes.item(i).getNodeValue();
			if(strName.equals("font-family")){
				setFontFamily(strValue);
			}else if(strName.equals("font-size")){
				setFontSize(PdfUtil.getSize(strValue));
			}else if(strName.equals("font-color")){
				setFontColor(PdfUtil.getColor(strValue));
			}else if(strName.equals("font-style")){
				setFontStyle(strValue);
			}else if(strName.equals("align-h")){
				super.setHorizontalAlignment(PdfUtil.getAlign(strValue));
			}else if(strName.equals("align-v")){
				super.setVerticalAlignment(PdfUtil.getAlign(strValue));
			}else if(strName.equals("height")){
				super.setMinimumHeight(PdfUtil.getSize(strValue));
			}else if(strName.equals("padding")){
				super.setPadding(PdfUtil.getSize(strValue));
			}else if(strName.equals("padding-left")){
				super.setPaddingLeft(PdfUtil.getSize(strValue));
			}else if(strName.equals("padding-right")){
				super.setPaddingRight(PdfUtil.getSize(strValue));
			}else if(strName.equals("padding-top")){
				super.setPaddingTop(PdfUtil.getSize(strValue));
			}else if(strName.equals("padding-bottom")){
				super.setPaddingBottom(PdfUtil.getSize(strValue));
			}else if(strName.equals("lotation")){
				//super.setLotation();
			}else if(strName.equals("background-color")){
				super.setBackgroundColor(PdfUtil.getColor(strValue));
			}else if(strName.equals("border")){
				//super.setBorder();
			}else if(strName.equals("border-color")){
				super.setBorderColor(PdfUtil.getColor(strValue));
			}else if(strName.equals("border-color-left")){
				super.setBorderColorLeft(PdfUtil.getColor(strValue));
			}else if(strName.equals("border-color-right")){
				super.setBorderColorRight(PdfUtil.getColor(strValue));
			}else if(strName.equals("border-color-top")){
				super.setBorderColorTop(PdfUtil.getColor(strValue));
			}else if(strName.equals("border-color-bottom")){
				super.setBorderColorBottom(PdfUtil.getColor(strValue));
			}else if(strName.equals("border-width")){
				super.setBorderWidth(PdfUtil.getSize(strValue));
			}else if(strName.equals("border-width-left")){
				super.setBorderWidthLeft(PdfUtil.getSize(strValue));
			}else if(strName.equals("border-width-right")){
				super.setBorderWidthRight(PdfUtil.getSize(strValue));
			}else if(strName.equals("border-width-top")){
				super.setBorderWidthTop(PdfUtil.getSize(strValue));
			}else if(strName.equals("border-width-bottom")){
				super.setBorderWidthBottom(PdfUtil.getSize(strValue));
			}

		}
	}

	PdfCellWrapper getCopy() throws Exception{
		PdfCellWrapper cell = new PdfCellWrapper();
		cell.setHorizontalAlignment(super.getHorizontalAlignment());
		cell.setVerticalAlignment(super.getVerticalAlignment());
		cell.setMinimumHeight(super.getMinimumHeight());
		cell.setPaddingLeft(super.getPaddingLeft());
		cell.setPaddingRight(super.getPaddingRight());
		cell.setPaddingTop(super.getPaddingTop());
		cell.setPaddingBottom(super.getPaddingBottom());
		cell.setRotation(super.getRotation());
		cell.setBackgroundColor(super.backgroundColor());
		cell.setBorder(super.border());
		cell.setBorderColorLeft(super.getBorderColorLeft());
		cell.setBorderColorRight(super.getBorderColorRight());
		cell.setBorderColorTop(super.getBorderColorTop());
		cell.setBorderColorBottom(super.getBorderColorBottom());
		cell.setBorderWidthLeft(super.getBorderWidthLeft());
		cell.setBorderWidthRight(super.getBorderWidthRight());
		cell.setBorderWidthTop(super.getBorderWidthTop());
		cell.setBorderWidthBottom(super.getBorderWidthBottom());

		cell.setFontFamily(this.strFontFamily);
		cell.setFontSize(this.fontM.size());
		cell.setFontStyle(this.fontM.style());
		cell.setFontColor(this.fontM.color());
		return cell;
	}

}
