package jp.veltec.pdf;

import java.util.*;
import java.io.*;
import javax.xml.*;
import javax.xml.parsers.*;
import org.w3c.dom.*;
import org.w3c.dom.Element;
import com.lowagie.text.*;			//iTextgAPI
import com.lowagie.text.pdf.*;		//iTextgAPI
import java.text.*;

public class PdfDocumentWrapper{
	public static final float fltM2P = 83f*12/350;

	public static DateFormat df = DateFormat.getDateTimeInstance(DateFormat.MEDIUM,
						   DateFormat.MEDIUM,
						   Locale.JAPAN);
	public static NumberFormat nf=NumberFormat.getCurrencyInstance();

	private org.w3c.dom.Element eleDoc;
	private com.lowagie.text.Document pdfDoc;
	private float fltWidth;
	private float fltHeight;
	private float fltMarginLeft;
	private float fltMarginRight;
	private float fltMarginTop;
	private float fltMarginBottom;
	private OutputStream osPdf;
	private HashMap<String,String> hmValues;

	public void setElement(org.w3c.dom.Element element){
		this.eleDoc = element;
	}

	public void setOutputStream(OutputStream os){
		this.osPdf = os;
	}

	public DateFormat getDf(){return this.df;}
	public NumberFormat getNf(){return this.nf;}
	public float getMarginLeft(){return this.fltMarginLeft;}
	public float getMarginRight(){return this.fltMarginRight;}
	public float getMarginTop(){return this.fltMarginTop;}
	public float getMarginBottomt(){return this.fltMarginBottom;}
	public float getWidth(){return this.fltWidth;}
	public float getHeight(){return this.fltHeight;}
	public void setValues(HashMap<String,String> values){
		this.hmValues = values;
	}

	public void process()throws Exception{
		String strSize = this.eleDoc.getAttribute("size");
		if(strSize!=null){
			if(strSize.equals("A4P")){
				this.fltWidth=210f*fltM2P;
				this.fltHeight=297f*fltM2P;
			}else if(strSize.equals("A4L")){
				this.fltWidth=297f*fltM2P;
				this.fltHeight=210f*fltM2P;
			}
		}

		strSize = this.eleDoc.getAttribute("margin-left");
		if(!strSize.equals("")){
			this.fltMarginLeft=PdfUtil.getSize(strSize);
		}

		strSize = this.eleDoc.getAttribute("margin-right");
		if(!strSize.equals("")){
			this.fltMarginRight=PdfUtil.getSize(strSize);
		}

		strSize = this.eleDoc.getAttribute("margin-top");
		if(!strSize.equals("")){
			this.fltMarginTop=PdfUtil.getSize(strSize);
		}
		strSize = this.eleDoc.getAttribute("margin-bottom");
		if(!strSize.equals("")){
			this.fltMarginBottom=PdfUtil.getSize(strSize);
		}

		this.pdfDoc = new com.lowagie.text.Document(
			new Rectangle(this.fltWidth,this.fltHeight), 
			this.fltMarginLeft,this.fltMarginRight, 
			this.fltMarginTop,this.fltMarginBottom);

	    PdfWriter pdfWriter = PdfWriter.getInstance(this.pdfDoc,this.osPdf);
		this.pdfDoc.open();
		PdfContentByte pcb = pdfWriter.getDirectContent();
		NodeList nlImage = this.eleDoc.getElementsByTagName("img");

		for(int i=0;i<nlImage.getLength();i++){
			Element eleImage = (Element)nlImage.item(i);
			String strImage = eleImage.getAttribute("src");
			Image image = Image.getInstance(strImage);
			String strBackGround = eleImage.getAttribute("background");
			if(strBackGround.equals("true")){
				String strImageWidth = eleImage.getAttribute("width");
				float fltImageWidth = PdfUtil.getSize(strImageWidth);
				String strImageHeight = eleImage.getAttribute("height");
				float fltImageHeight = PdfUtil.getSize(strImageHeight);
				image.scaleAbsolute(fltImageWidth,fltImageHeight);
				String strTop = eleImage.getAttribute("top");
				float fltTop = PdfUtil.getSize(strTop);
				String strLeft = eleImage.getAttribute("left");
				float fltLeft = PdfUtil.getSize(strLeft);
				image.setAbsolutePosition(fltLeft,this.fltHeight-fltTop-fltImageHeight);
				pcb.addImage(image);
			}
		}

		NodeList nlTables = this.eleDoc.getElementsByTagName("table");
		for(int i=0;i<nlTables.getLength();i++){
			PdfTableWrapper table = new PdfTableWrapper();
			table.setElement((org.w3c.dom.Element)nlTables.item(i));
			table.setValues(this.hmValues);
			this.pdfDoc.add(table.getTable());
		}

		for(int i=0;i<nlImage.getLength();i++){
			Element eleImage = (Element)nlImage.item(i);
			String strImage = eleImage.getAttribute("src");
			Image image = Image.getInstance(strImage);
			String strBackGround = eleImage.getAttribute("background");
			if(!strBackGround.equals("true")){
				String strImageWidth = eleImage.getAttribute("width");
				float fltImageWidth = PdfUtil.getSize(strImageWidth);
				String strImageHeight = eleImage.getAttribute("height");
				float fltImageHeight = PdfUtil.getSize(strImageHeight);
				image.scaleAbsolute(fltImageWidth,fltImageHeight);
				String strTop = eleImage.getAttribute("top");
				float fltTop = PdfUtil.getSize(strTop);
				String strLeft = eleImage.getAttribute("left");
				float fltLeft = PdfUtil.getSize(strLeft);
				image.setAbsolutePosition(fltLeft,this.fltHeight-fltTop-fltImageHeight);
				pcb.addImage(image);
			}
		}

		//this.pdfDoc.add(getTableTest());
		this.pdfDoc.close();
	}

}

